@@ -15,11 +15,11 @@ NULL
 #> NULL
 
 # declaring varibles to avoid R CMD check notes.
-# those are mostly column names that occur in with, within, subset functioncs,
+# those are mostly column names that occur in with, within, subset functions,
 # dplyr verbs and ggplot calls.
 globalVariables(c(
   "interval", "trt", "method", "x", "name", "value", "level", "y", "n_pat",
-  "surv_a", "surv_b", "haz_a", "haz_b", "hr"
+  "surv_a", "surv_b", "haz_a", "haz_b", "hr", "x_split"
 ))
 
 
